@@ -2,7 +2,6 @@
 import os
 #import proj as p
 try:
-  import cli
   import time
   import sys
   import getopt
@@ -20,10 +19,22 @@ try:
 except ImportError:
   print("Installing dependencies of build...")
   os.system("pip install tqdm")
+  import time
+  import sys
+  import getopt
+  import subprocess
 
+  import sys
+  from sys import platform
+  import json
+  import base64
+  import shutil
+
+  from tqdm import tqdm
 
 import json
 import os
+import sys
 
 
 pos = ["name","run","version","dependencies","modules","projects","authors"]
